<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       www.orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Sci
 * @subpackage Vpc_Sci/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Sci
 * @subpackage Vpc_Sci/admin
 * @author     ORION <support@orionorigin.com>
 */
class Vpc_Sci_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param    string $plugin_name       The name of this plugin.
	 * @param    string $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Sci_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Sci_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Sci_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Sci_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Sci_Updater
	 */
	public function get_updater()
	{
		if (class_exists('vpc')) {
			do_action('vpc_before_init_updater');
			require_once VPC_SCI_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-sci-updater.php';
			$updater = new Vpc_Sci_Updater();
			$updater->init();
			require_once VPC_SCI_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-sci-updating-manager.php';
			$updater->setUpdateManager(new Vpc_Sci_Updating_Manager(VPC_SCI_VERSION, $updater->versionUrl(), VPC_SCI_MAIN_FILE));
			do_action('vpc_after_init_updater');
			return $updater;
		}
	}

	/**
	 * Function to add save preview settings.
	 *
	 * @param array $skin_settings The save preview settings parameter.
	 * @return array
	 */
	public function add_save_settings($skin_settings)
	{
		$skin_settings[] = array(
			'type' => 'sectionbegin',
			'id'   => 'vpc-save-preview-container',
		);
		$skin_settings[] = array(
			'title'   => __('Activate Save Configuration option', 'vpc-sci'),
			'name'    => 'vpc-config[save-config]',
			'type'    => 'radio',
			'options' => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default' => 'No',
			'class'   => '',
			'desc'    => __('Enable the ability to save configuration for customer by choosing YES. Disable by choosing NO.', 'vpc-sci'),
		);
		$skin_settings[] = array(
			'title'   => __('Require form builder fields ', 'vpc-sci'),
			'name'    => 'vpc-config[require-fields]',
			'type'    => 'radio',
			'options' => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default' => 'Yes',
			'class'   => '',
			'desc'    => __('Fill the form builder require fields before downloading the image of the configurator.', 'vpc-sci'),
		);
		$skin_settings[] = array('type' => 'sectionend');
		return $skin_settings;
	}
	/**
	 * Function to add save preview settings.
	 *
	 * @param array $global_settings The save preview global settings parameter.
	 * @return array
	 */
	public function add_global_settings($global_settings)
	{
		$begin = array(
			'type'  => 'sectionbegin',
			'id'    => 'vpc-sci-container',
			'table' => 'options',
		);

		$end = array('type' => 'sectionend');

		$license_key = array(
			'title'   => __('Save configuration image add on license key', 'vpc'),
			'name'    => 'vpc-options[purchase-code-save-custom-image-add-on]',
			'type'    => 'text',
			'desc'    => __('This is the licence key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc'),
			'default' => '',
		);


		array_push($global_settings, $begin);
		array_push($global_settings, $license_key);
		array_push($global_settings, $end);
		return $global_settings;
	}
}
