<?php

/**
 * The file that defines all the global functions
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Sci
 * @subpackage Vpc_Sci/includes
 */

/**
 * Function to clean a configuration's recap.
 *
 * @param  array $dirty_recap Unclean configuration recap.
 * @return array              Clean configuration's recap.
 */
function vpc_sci_clean_recap($dirty_recap)
{
	$recap = array();
	if (!empty($dirty_recap)) {
		$recap = $dirty_recap;
		if (isset($recap['action'])) {
			unset($recap['action']);
		}
		if (isset($recap['nonce'])) {
			unset($recap['nonce']);
		}
		if (isset($recap['id_ofb'])) {
			unset($recap['id_ofb']);
		}

		foreach ($dirty_recap as $key => $value) {
			if ('' === $value) {
				unset($recap[$key]);
				$text_properties = $key . ' properties';
				if (isset($recap[$text_properties])) {
					unset($recap[$text_properties]);
				}
			}
		}
	}
	return $recap;
}

/**
 * Function to sanitize an array.
 *
 * @param  array $data Unsanitized array.
 * @return array        Sanitized array.
 */
function vpc_sci_sanitize_array($data)
{
	if (is_array($data)) {
		foreach ((array) $data as $k => $v) {
			if (is_array($v)) {
				$data[$k] = vpc_sci_sanitize_array($v);
			} else {
				$data[$k] = sanitize_text_field($v);
			}
		}
	} else {
		$data = sanitize_text_field($data);
	}
	return $data;
}
